summaryrefslogtreecommitdiffstats
path: root/PerlTQt/examples/buttongroups/ButtonsGroups.pm
diff options
context:
space:
mode:
Diffstat (limited to 'PerlTQt/examples/buttongroups/ButtonsGroups.pm')
-rw-r--r--PerlTQt/examples/buttongroups/ButtonsGroups.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/PerlTQt/examples/buttongroups/ButtonsGroups.pm b/PerlTQt/examples/buttongroups/ButtonsGroups.pm
index 106cf1b..b842ab2 100644
--- a/PerlTQt/examples/buttongroups/ButtonsGroups.pm
+++ b/PerlTQt/examples/buttongroups/ButtonsGroups.pm
@@ -67,8 +67,8 @@ sub NEW {
# insert a checkbox
state = TQt::CheckBox("E&nable Radiobuttons", $bgrp3);
state->setChecked(1);
- # ...and connect its TQT_SIGNAL clicked() with the TQT_SLOT slotChangeGrp3State()
- this->connect(state, TQT_SIGNAL('clicked()'), TQT_SLOT('slotChangeGrp3State()'));
+ # ...and connect its TQ_SIGNAL clicked() with the TQ_SLOT slotChangeGrp3State()
+ this->connect(state, TQ_SIGNAL('clicked()'), TQ_SLOT('slotChangeGrp3State()'));
# ----------- fourth group
@@ -90,7 +90,7 @@ sub NEW {
}
#
-# TQT_SLOT slotChangeGrp3State()
+# TQ_SLOT slotChangeGrp3State()
#
# enables/disables the radiobuttons of the third buttongroup
#